<template>
    <tr class="m-color b-font" style="text-align: center">应急预案/应急演练</tr>
    <tr>
      <td class="w-20 m-color">预案名称</td>
      <td class="w-20 m-color">是否演练</td>
      <td class="w-20 m-color">演练情况</td>
      <td class="w-20 m-color">是否备案</td>
      <td class="w-20 m-color">操作</td>
    </tr>
    <tr v-for="(item,index) in selectEmergencyState.emergencyList" :key="index">
        <td class="w-20">
            <el-input :disabled="selectEmergencyState.disabled" v-model="item.emergencyPlanName" />
        </td>
        <td class="w-20">
            <el-radio-group :disabled="selectEmergencyState.disabled"  v-model="item.emergencyDrillStatus">
              <el-radio label="是">是</el-radio>
              <el-radio label="否">否</el-radio>
            </el-radio-group>
        </td>
        <td class="w-20">
            <el-input :disabled="selectEmergencyState.disabled" v-model="item.emergencyDrill" placeholder="未演练则填“无”"/>
        </td>
        <td class="w-20">
            <el-radio-group :disabled="selectEmergencyState.disabled"  v-model="item.emergencyPlan">
              <el-radio label="是">是</el-radio>
              <el-radio label="否">否</el-radio>
            </el-radio-group>
        </td>
        <td class="w-20">
          <el-button :disabled="selectEmergencyState.disabled" type="danger" @click="deleteEmergencyItem(index)">删除</el-button>
        </td>
    </tr>
    <tr style="text-align: center" v-if="!selectEmergencyState.disabled">
        <el-button type="primary" shape="round" @click="addEmergencyItem()">
            添加一条
        </el-button>
    </tr>
</template>

<script setup lang="ts">
import {defineAsyncComponent, onMounted, reactive, ref, watchEffect} from "vue";
import {ElMessage} from "element-plus";
let props = defineProps({
    disabled: Boolean,
    data: Array<emergencyListType>
});

const selectEmergencyState = reactive<SelectEmergencyType>({
    disabled: false,
    emergencyList: []
})

const addEmergencyItem = () => {
    selectEmergencyState.emergencyList.push({ emergencyPlanName: '', emergencyDrillStatus: '', emergencyDrill: '', emergencyPlan: '' });
};

watchEffect(() => {
    selectEmergencyState.emergencyList = props.data as Array<emergencyListType>
    selectEmergencyState.disabled = props.disabled
});

const deleteEmergencyItem = (index: number) => {
    selectEmergencyState.emergencyList.splice(index,1);
};

const formatList = (formatList: Array<emergencyListType>) => {
    selectEmergencyState.emergencyList = formatList
};

defineExpose({
    dataList: selectEmergencyState.emergencyList,
    formatList
});


onMounted(() => {

});
</script>

<style scoped lang="scss">
.site-layout-background {
    background: #fff;
}

.report-table {
    width: 100%;
    border-collapse: collapse;
    border: 1px solid #337ecc;
    margin: 20px 0;

    th {
        padding: 10px 0;
        border: 1px solid #337ecc;
        border-left: none;
    }

    tr {
        width: 100%;
        height: 44px;
        line-height: 42px;
        border-bottom: 1px solid #ccc;

        &:last-of-type {
            border-bottom: none;
        }

        td {
            border-right: 1px solid #ccc;
            display: inline-block;
            height: 44px;
            vertical-align: middle;
            text-align: center;
            line-height: 42px;

            &:last-of-type {
                border-right: none;
            }

            &.required {
              &::before {
                content: "*";
                display: inline-block;
                color: red;
              }
            }

            &.w-14 {
                width: calc((100/7)/100 * 100%);
            }

            &.w-16 {
                width: calc((100/6)/100 * 100%);
            }

            &.w-18 {
                width: 16.59%;
            }

            &.w-20 {
                width: 20%;
            }

            &.w-25 {
                width: 25%;
            }

            &.w-50 {
                width: 50%;
            }

            &.w-75 {
                width: 75%;
            }

            .ant-input {
                height: 100%;
                border: none;
                background: #f5f7fa;
            }

            .ant-picker {
                width: 100%;
                height: 100%;
            }
            :deep(.el-input__wrapper ){
              box-shadow: none;
            }
        }
    }

    .b-font {
        font-size: 16px;
        font-weight: bolder;
    }
}

.m-color {
    color: #0c4995;
}
</style>
